==> openjdk-19_19~23ea.orig.tar.xz: openjdk-19-19~23ea/test/hotspot/jtreg/compiler/lib/ir_framework/driver/irmatching/irrule/CountsRegexFailure.java <==
/*
 * Copyright (c) 2022, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

package compiler.lib.ir_framework.driver.irmatching.irrule;

import compiler.lib.ir_framework.shared.Comparison;

import java.util.List;

/**
 * This class represents an IR matching failure of a regex of a counts attribute of an IR rule.
 *
 * @see Counts
 */
class CountsRegexFailure extends RegexFailure {
    String failedComparison;

    public CountsRegexFailure(String nodeRegex, int nodeId, long foundValue, Comparison<Long> comparison, List<String> matches) {
        super(nodeRegex, nodeId, matches);
        this.failedComparison = "[found] " + foundValue + " " + comparison.getComparator() + " "
                                + comparison.getGivenValue() + " [given]";
    }

    @Override
    public String buildFailureMessage() {
        return getRegexLine()
               + getFailedComparison()
               + getMatchedNodesBlock();
    }

    private String getFailedComparison() {
        return "         - Failed comparison: " + failedComparison + System.lineSeparator();
    }

    @Override
    protected String getMatchedNodesBlock() {
        if (matches.isEmpty()) {
            return getEmptyNodeMatchesLine();
        } else {
            return super.getMatchedNodesBlock();
        }
    }

    private String getEmptyNodeMatchesLine() {
        return getMatchedNodesWhiteSpace() + "- No nodes matched!" + System.lineSeparator();
    }

    @Override
    protected String getMatchedPrefix() {
        return "Matched";
    }

}

==> openjdk-20_20~20ea.orig.tar.xz: openjdk-20-20~20ea/test/hotspot/jtreg/compiler/lib/ir_framework/driver/irmatching/irrule/CountsRegexFailure.java <==
/*
 * Copyright (c) 2022, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

package compiler.lib.ir_framework.driver.irmatching.irrule;

import compiler.lib.ir_framework.shared.Comparison;

import java.util.List;

/**
 * This class represents an IR matching failure of a regex of a counts attribute of an IR rule.
 *
 * @see Counts
 */
class CountsRegexFailure extends RegexFailure {
    String failedComparison;

    public CountsRegexFailure(String nodeRegex, int nodeId, int foundValue, Comparison<Integer> comparison,
                              List<String> matches) {
        super(nodeRegex, nodeId, matches);
        this.failedComparison = "[found] " + foundValue + " " + comparison.getComparator() + " "
                                + comparison.getGivenValue() + " [given]";
    }

    @Override
    public String buildFailureMessage() {
        return getRegexLine()
               + getFailedComparison()
               + getMatchedNodesBlock();
    }

    private String getFailedComparison() {
        return "         - Failed comparison: " + failedComparison + System.lineSeparator();
    }

    @Override
    protected String getMatchedNodesBlock() {
        if (matches.isEmpty()) {
            return getEmptyNodeMatchesLine();
        } else {
            return super.getMatchedNodesBlock();
        }
    }

    private String getEmptyNodeMatchesLine() {
        return getMatchedNodesWhiteSpace() + "- No nodes matched!" + System.lineSeparator();
    }

    @Override
    protected String getMatchedPrefix() {
        return "Matched";
    }

}
